==> blesta-5.10.2.zip: blesta/language/tr_tr/admin_company_plugins.php <==
<?php
/**
 * Admin Company Plugins
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyPlugins.settings.actions_heading_secondary'] = 'İkincil Seçenekler';
$lang['AdminCompanyPlugins.settings.actions_heading_sub'] = 'Alt Seçenekler';
$lang['AdminCompanyPlugins.settings.actions_uri'] = 'URI: %1$s';
$lang['AdminCompanyPlugins.settings.actions_description'] = 'Eylemler, navigasyon bağlantıları veya widget\'lar gibi eklenti adına yönetici ve istemci arayüzlerinde nelerin görüntülenebileceğini tanımlar.';
$lang['AdminCompanyPlugins.settings.events_no_results'] = 'Bu eklenti için ayarlanmış bir etkinlik yok.';
$lang['AdminCompanyPlugins.settings.automation_no_results'] = 'Bu eklenti için ayarlanmış herhangi bir otomasyon görevi yoktur.';
$lang['AdminCompanyPlugins.settings.actions_no_results'] = 'Bu eklenti için ayarlanmış herhangi bir eylem yoktur.';
$lang['AdminCompanyPlugins.settings.events_description'] = 'Eklenti aşağıdaki olayları dinler ve bunlar gerçekleştiğinde bazı eylemler gerçekleştirir.';
$lang['AdminCompanyPlugins.settings.automation_description'] = 'Eklenti, cron tarafından çalıştırıldığında belirli eylemleri gerçekleştirmek için aşağıdaki otomasyon görevlerini kaydetmiştir.';
$lang['AdminCompanyPlugins.settings.tab_events'] = 'Etkinlikler';
$lang['AdminCompanyPlugins.settings.tab_actions'] = 'Eylemler';
$lang['AdminCompanyPlugins.settings.tab_automation'] = 'Otomasyon';
$lang['AdminCompanyPlugins.settings.page_title'] = '1$s Ayarlar';
$lang['AdminCompanyPlugins.settings.field_submit'] = 'Ayarları Güncelle';
$lang['AdminCompanyPlugins.settings.field_enabled'] = 'Etkin';
$lang['AdminCompanyPlugins.installed.text_none'] = 'Yüklü eklenti yok.';
$lang['AdminCompanyPlugins.installed.btn_upgrade'] = 'Yükseltme';
$lang['AdminCompanyPlugins.installed.btn_settings'] = 'Ayarlar';
$lang['AdminCompanyPlugins.installed.btn_manage'] = 'Yönetmek';
$lang['AdminCompanyPlugins.installed.btn_enable'] = 'Etkinleştir';
$lang['AdminCompanyPlugins.installed.btn_disable'] = 'Devre dışı bırak';
$lang['AdminCompanyPlugins.installed.btn_uninstall'] = 'Kaldırma';
$lang['AdminCompanyPlugins.installed.confirm_enable'] = 'Bu eklentiyi gerçekten etkinleştirdiniz mi?';
$lang['AdminCompanyPlugins.installed.confirm_disable'] = 'Bu eklentiyi gerçekten devre dışı mı bırakayım?';
$lang['AdminCompanyPlugins.installed.confirm_uninstall'] = 'Bu eklentiyi gerçekten kaldırıyor musunuz?';
$lang['AdminCompanyPlugins.installed.text_author'] = 'Yazar:';
$lang['AdminCompanyPlugins.installed.text_version'] = '(ver %1$s)';
$lang['AdminCompanyPlugins.installed.boxtitle_plugin'] = 'Eklentiler';
$lang['AdminCompanyPlugins.installed.page_title'] = 'Ayarlar > Şirket > Eklentiler > Yüklü';
$lang['AdminCompanyPlugins.available.text_none'] = 'Mevcut eklenti yok.';
$lang['AdminCompanyPlugins.available.btn_install'] = 'Kurulum';
$lang['AdminCompanyPlugins.available.text_author'] = 'Yazar:';
$lang['AdminCompanyPlugins.available.text_version'] = '(ver %1$s)';
$lang['AdminCompanyPlugins.available.boxtitle_plugins'] = 'Eklentiler';
$lang['AdminCompanyPlugins.available.page_title'] = 'Ayarlar > Şirket > Eklentiler > Kullanılabilir';
$lang['AdminCompanyPlugins.settings.event.users.logout'] = 'Bu olay, bir kullanıcı oturumu kapattığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.users.login'] = 'Bu olay, bir kullanıcı oturum açtığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.users.delete'] = 'Bu olay, bir kullanıcı silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.transactions.edit'] = 'Bu olay, bir işlem güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.transactions.add'] = 'Bu olay, bir işlem oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.staff.edit'] = 'Bu olay, bir personel üyesi güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.staff.add'] = 'Bu olay, bir personel üyesi oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.services.unsuspend'] = 'Bu olay, bir hizmet askıya alınmadığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.services.suspend'] = 'Bu olay, bir hizmet askıya alındığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.services.cancel'] = 'Bu olay, bir hizmet iptal edildiğinde veya iptal edilmesi planlandığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.services.edit'] = 'Bu olay, bir hizmet güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.services.add'] = 'Bu olay, bir hizmet oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.report.clientdata'] = 'Bu olay, Müşteri Veri Taşınabilirliği raporu oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.packages.delete'] = 'Bu olay, bir paket silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.packages.edit'] = 'Bu olay, bir paket güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.packages.add'] = 'Bu olay, bir paket oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.navigation.getsearchoptions'] = 'Bu olay, personel için arama seçenekleri görüntülendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.modulemanager.delete'] = 'Bu olay, bir modül kaldırıldığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.modulemanager.add'] = 'Bu olay, bir modül yüklendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.invoices.setclosed'] = 'Bu olay, bir fatura kapatıldığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.invoices.edit'] = 'Bu olay, bir fatura güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.invoices.add'] = 'Bu olay, bir fatura oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.gatewaymanager.delete'] = 'Bu olay, bir ağ geçidi kaldırıldığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.gatewaymanager.edit'] = 'Bu olay, bir ağ geçidi güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.gatewaymanager.add'] = 'Bu olay, bir ağ geçidi kurulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.emails.sendcustom'] = 'Bu olay, özel bir e-posta gönderildiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.emails.send'] = 'Bu olay, bir e-posta şablonu gönderildiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.contacts.delete'] = 'Bu olay, bir müşteri irtibatı silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.contacts.edit'] = 'Bu olay, bir müşteri irtibatı güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.contacts.add'] = 'Bu olay, bir müşteri irtibatı oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.companies.delete'] = 'Bu olay, bir şirket silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.companies.edit'] = 'Bu olay, bir şirket güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.companies.add'] = 'Bu olay, bir şirket oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.deletenote'] = 'Bu olay, bir müşteri notu silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.delete'] = 'Bu olay, bir istemci silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.editnote'] = 'Bu olay, bir müşteri notu güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.edit'] = 'Bu olay, bir istemci güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.create'] = 'Bu olay, bir istemci oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.addnote'] = 'Bu olay, bir müşteri notu oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.add'] = 'Bu olay, bir müşteri eklendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clientgroups.delete'] = 'Bu olay, bir müşteri grubu silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clientgroups.edit'] = 'Bu olay, bir müşteri grubu güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clientgroups.add'] = 'Bu olay, bir müşteri grubu oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.calendarevents.delete'] = 'Bu olay, bir takvim olayı silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.calendarevents.edit'] = 'Bu olay, bir takvim olayı güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.calendarevents.add'] = 'Bu olay, bir takvim olayı oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.appcontroller.structure'] = 'Bu olay, AJAX aracılığıyla olmayan bir sayfa yüklemesi gerçekleştiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.appcontroller.preaction'] = 'Bu olay, bir sayfa yüklendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.!tab.available'] = 'Mevcut';
$lang['AdminCompanyPlugins.!tab.installed'] = 'Yüklendi';
$lang['AdminCompanyPlugins.!error.setting_controller_invalid'] = 'Belirtilen ayar denetleyicisi bu eklenti için mevcut değil.';
$lang['AdminCompanyPlugins.!success.events_updated'] = 'Olay ayarları başarıyla güncellendi.';
$lang['AdminCompanyPlugins.!success.actions_updated'] = 'Eylem ayarları başarıyla güncellendi.';
$lang['AdminCompanyPlugins.!success.automation_updated'] = 'Otomasyon ayarları başarıyla güncellendi.';
$lang['AdminCompanyPlugins.!success.disabled'] = 'Eklenti başarıyla devre dışı bırakıldı.';
$lang['AdminCompanyPlugins.!success.enabled'] = 'Eklenti başarıyla etkinleştirildi.';
$lang['AdminCompanyPlugins.!success.upgraded'] = 'Eklenti başarıyla yükseltildi.';
$lang['AdminCompanyPlugins.!success.uninstalled'] = 'Eklenti başarıyla kaldırıldı.';
$lang['AdminCompanyPlugins.!success.installed'] = 'Eklenti başarıyla yüklendi. Çeşitli kaynaklar için ACL izinleri kaydetmiş olabilir. Bu kaynaklara erişmek için personel grubunuza bu izinlere erişim izni vermeniz gerekebilir.';

==> blesta-5.11.4.zip: blesta/language/tr_tr/admin_company_plugins.php <==
<?php
/**
 * Admin Company Plugins
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyPlugins.settings.actions_heading_secondary'] = 'İkincil Seçenekler';
$lang['AdminCompanyPlugins.settings.actions_heading_sub'] = 'Alt Seçenekler';
$lang['AdminCompanyPlugins.settings.actions_uri'] = 'URI: %1$s';
$lang['AdminCompanyPlugins.settings.actions_description'] = 'Eylemler, navigasyon bağlantıları veya widget\'lar gibi eklenti adına yönetici ve istemci arayüzlerinde nelerin görüntülenebileceğini tanımlar.';
$lang['AdminCompanyPlugins.settings.events_no_results'] = 'Bu eklenti için ayarlanmış bir etkinlik yok.';
$lang['AdminCompanyPlugins.settings.automation_no_results'] = 'Bu eklenti için ayarlanmış herhangi bir otomasyon görevi yoktur.';
$lang['AdminCompanyPlugins.settings.actions_no_results'] = 'Bu eklenti için ayarlanmış herhangi bir eylem yoktur.';
$lang['AdminCompanyPlugins.settings.events_description'] = 'Eklenti aşağıdaki olayları dinler ve bunlar gerçekleştiğinde bazı eylemler gerçekleştirir.';
$lang['AdminCompanyPlugins.settings.automation_description'] = 'Eklenti, cron tarafından çalıştırıldığında belirli eylemleri gerçekleştirmek için aşağıdaki otomasyon görevlerini kaydetmiştir.';
$lang['AdminCompanyPlugins.settings.tab_events'] = 'Etkinlikler';
$lang['AdminCompanyPlugins.settings.tab_actions'] = 'Eylemler';
$lang['AdminCompanyPlugins.settings.tab_automation'] = 'Otomasyon';
$lang['AdminCompanyPlugins.settings.field_submit'] = 'Ayarları Güncelle';
$lang['AdminCompanyPlugins.settings.field_enabled'] = 'Etkin';
$lang['AdminCompanyPlugins.installed.text_none'] = 'Yüklü eklenti yok.';
$lang['AdminCompanyPlugins.installed.btn_upgrade'] = 'Yükseltme';
$lang['AdminCompanyPlugins.installed.btn_settings'] = 'Ayarlar';
$lang['AdminCompanyPlugins.installed.btn_manage'] = 'Yönetmek';
$lang['AdminCompanyPlugins.installed.btn_enable'] = 'Etkinleştir';
$lang['AdminCompanyPlugins.installed.btn_disable'] = 'Devre dışı bırak';
$lang['AdminCompanyPlugins.installed.btn_uninstall'] = 'Kaldırma';
$lang['AdminCompanyPlugins.installed.confirm_enable'] = 'Bu eklentiyi gerçekten etkinleştirdiniz mi?';
$lang['AdminCompanyPlugins.installed.confirm_disable'] = 'Bu eklentiyi gerçekten devre dışı mı bırakayım?';
$lang['AdminCompanyPlugins.installed.confirm_uninstall'] = 'Bu eklentiyi gerçekten kaldırıyor musunuz?';
$lang['AdminCompanyPlugins.installed.text_author'] = 'Yazar:';
$lang['AdminCompanyPlugins.installed.text_version'] = '(ver %1$s)';
$lang['AdminCompanyPlugins.installed.boxtitle_plugin'] = 'Eklentiler';
$lang['AdminCompanyPlugins.installed.page_title'] = 'Ayarlar > Şirket > Eklentiler > Yüklü';
$lang['AdminCompanyPlugins.available.text_none'] = 'Mevcut eklenti yok.';
$lang['AdminCompanyPlugins.available.btn_install'] = 'Kurulum';
$lang['AdminCompanyPlugins.available.text_author'] = 'Yazar:';
$lang['AdminCompanyPlugins.available.text_version'] = '(ver %1$s)';
$lang['AdminCompanyPlugins.available.boxtitle_plugins'] = 'Eklentiler';
$lang['AdminCompanyPlugins.available.page_title'] = 'Ayarlar > Şirket > Eklentiler > Kullanılabilir';
$lang['AdminCompanyPlugins.settings.event.users.logout'] = 'Bu olay, bir kullanıcı oturumu kapattığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.users.login'] = 'Bu olay, bir kullanıcı oturum açtığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.users.delete'] = 'Bu olay, bir kullanıcı silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.transactions.edit'] = 'Bu olay, bir işlem güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.transactions.add'] = 'Bu olay, bir işlem oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.staff.edit'] = 'Bu olay, bir personel üyesi güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.staff.add'] = 'Bu olay, bir personel üyesi oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.services.unsuspend'] = 'Bu olay, bir hizmet askıya alınmadığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.services.suspend'] = 'Bu olay, bir hizmet askıya alındığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.services.cancel'] = 'Bu olay, bir hizmet iptal edildiğinde veya iptal edilmesi planlandığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.services.edit'] = 'Bu olay, bir hizmet güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.services.add'] = 'Bu olay, bir hizmet oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.report.clientdata'] = 'Bu olay, Müşteri Veri Taşınabilirliği raporu oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.packages.delete'] = 'Bu olay, bir paket silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.packages.edit'] = 'Bu olay, bir paket güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.packages.add'] = 'Bu olay, bir paket oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.navigation.getsearchoptions'] = 'Bu olay, personel için arama seçenekleri görüntülendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.modulemanager.delete'] = 'Bu olay, bir modül kaldırıldığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.modulemanager.add'] = 'Bu olay, bir modül yüklendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.invoices.setclosed'] = 'Bu olay, bir fatura kapatıldığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.invoices.edit'] = 'Bu olay, bir fatura güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.invoices.add'] = 'Bu olay, bir fatura oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.gatewaymanager.delete'] = 'Bu olay, bir ağ geçidi kaldırıldığında tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.gatewaymanager.edit'] = 'Bu olay, bir ağ geçidi güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.gatewaymanager.add'] = 'Bu olay, bir ağ geçidi kurulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.emails.sendcustom'] = 'Bu olay, özel bir e-posta gönderildiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.emails.send'] = 'Bu olay, bir e-posta şablonu gönderildiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.contacts.delete'] = 'Bu olay, bir müşteri irtibatı silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.contacts.edit'] = 'Bu olay, bir müşteri irtibatı güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.contacts.add'] = 'Bu olay, bir müşteri irtibatı oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.companies.delete'] = 'Bu olay, bir şirket silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.companies.edit'] = 'Bu olay, bir şirket güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.companies.add'] = 'Bu olay, bir şirket oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.deletenote'] = 'Bu olay, bir müşteri notu silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.delete'] = 'Bu olay, bir istemci silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.editnote'] = 'Bu olay, bir müşteri notu güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.edit'] = 'Bu olay, bir istemci güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.create'] = 'Bu olay, bir istemci oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.addnote'] = 'Bu olay, bir müşteri notu oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clients.add'] = 'Bu olay, bir müşteri eklendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clientgroups.delete'] = 'Bu olay, bir müşteri grubu silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clientgroups.edit'] = 'Bu olay, bir müşteri grubu güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.clientgroups.add'] = 'Bu olay, bir müşteri grubu oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.calendarevents.delete'] = 'Bu olay, bir takvim olayı silindiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.calendarevents.edit'] = 'Bu olay, bir takvim olayı güncellendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.calendarevents.add'] = 'Bu olay, bir takvim olayı oluşturulduğunda tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.appcontroller.structure'] = 'Bu olay, AJAX aracılığıyla olmayan bir sayfa yüklemesi gerçekleştiğinde tetiklenir.';
$lang['AdminCompanyPlugins.settings.event.appcontroller.preaction'] = 'Bu olay, bir sayfa yüklendiğinde tetiklenir.';
$lang['AdminCompanyPlugins.!tab.available'] = 'Mevcut';
$lang['AdminCompanyPlugins.!tab.installed'] = 'Yüklendi';
$lang['AdminCompanyPlugins.!error.setting_controller_invalid'] = 'Belirtilen ayar denetleyicisi bu eklenti için mevcut değil.';
$lang['AdminCompanyPlugins.!success.events_updated'] = 'Olay ayarları başarıyla güncellendi.';
$lang['AdminCompanyPlugins.!success.actions_updated'] = 'Eylem ayarları başarıyla güncellendi.';
$lang['AdminCompanyPlugins.!success.automation_updated'] = 'Otomasyon ayarları başarıyla güncellendi.';
$lang['AdminCompanyPlugins.!success.disabled'] = 'Eklenti başarıyla devre dışı bırakıldı.';
$lang['AdminCompanyPlugins.!success.enabled'] = 'Eklenti başarıyla etkinleştirildi.';
$lang['AdminCompanyPlugins.!success.upgraded'] = 'Eklenti başarıyla yükseltildi.';
$lang['AdminCompanyPlugins.!success.uninstalled'] = 'Eklenti başarıyla kaldırıldı.';
$lang['AdminCompanyPlugins.!success.installed'] = 'Eklenti başarıyla yüklendi. Çeşitli kaynaklar için ACL izinleri kaydetmiş olabilir. Bu kaynaklara erişmek için personel grubunuza bu izinlere erişim izni vermeniz gerekebilir.';
$lang['AdminCompanyPlugins.settings.page_title'] = '%1$s Ayarlar';
